@@ -110,6 +110,9 @@ class VCSFileInitHook(hook.Hook):
         if not os.access(cacheroot, os.W_OK):
             raise ValueError('directory %r is not writable (check "local-repo-'
                              'cache-root" option)' % cacheroot)
+        hgrcpath = self.repo.config['hgrc-path']
+        if hgrcpath is not None:
+            os.environ['HGRCPATH'] = hgrcpath
 
 
 
@@ -455,9 +458,6 @@ def _refresh_repos(repo, eids=None, bridge=bridge):
     '''
     with repo.internal_session() as session:
         config = session.vreg.config
-        hgrcpath = repo.config['hgrc-path']
-        if hgrcpath is not None:
-            os.environ['HGRCPATH'] = hgrcpath
         rql = ('Any R, RT, RE, RLC, RSU, RP, RIRC WHERE R is Repository, '
                'NOT (R local_cache NULL AND R path NULL),'
                'R type RT, R encoding RE, R local_cache RLC, R source_url RSU, R path RP,'
